<?php
namespace Teknisa\CADCTB\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use \Teknisa\CADCTB\Controllers\TeknisaCrud;
use Teknisa\CADCTB\Services\Ctb27200RegistroAjustePeriodoBaseService;



class Ctb27200RegistroAjustePeriodoBaseController extends TeknisaCrud {
    protected $dataSourceName = 'm300a_lalura_lalurpartea';
    protected $dataSourceNameToSave = 'm300a_lalura';
    protected $parameterBagColumns = array("P_DTFINAL", "P_DTINICIAL", "P_CDEMPRESA", "P_IDTRIBUTO");
    protected $registroAjustePeriodoBaseService = '';


    public function __construct($crudService, $parameterBagColumns, Ctb27200RegistroAjustePeriodoBaseService $registroAjustePeriodoBaseService) {
        $this->crudService = $crudService;
        $this->registroAjustePeriodoBaseService =  $registroAjustePeriodoBaseService;
        parent::__construct($crudService, $parameterBagColumns);
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try{    
            $conditions = $request->getFilterCriteria()->getConditions();
            foreach($conditions as $condition) {
                if($condition["columnName"] == 'IDTRIBUTO') {
                    if($condition["value"] == 'I') {
                        $this->dataSourceName = 'm300a_lalura_lalurpartea';
                    }
                    if($condition["value"] == 'C') {
                        $this->dataSourceName = 'm350a_lacs_lalurpartea';
                    }
                    
                }
            }
            parent::find($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveRegistro(DTO\Request $request, DTO\Response $response) {
        try{
            $this->registroAjustePeriodoBaseService->entityManager->beginTransaction();
            
            $row = $request->getRow();
            
            $this->registroAjustePeriodoBaseService->saveRegistro($row);
            
            
            $this->registroAjustePeriodoBaseService->entityManager->commit();
            
        }
        catch (\Exception $e) {
            $this->registroAjustePeriodoBaseService->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveLancamentos(DTO\Request $request, DTO\Response $response){
        try{
            $this->registroAjustePeriodoBaseService->entityManager->beginTransaction();
            
            $row = $request->getRow();
            
            $this->registroAjustePeriodoBaseService->saveParteA($row);
            
            $this->registroAjustePeriodoBaseService->entityManager->commit();
        }
        catch (\Exception $e) {
            $this->registroAjustePeriodoBaseService->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
    
    public function deleteLancamentos(DTO\Request $request, DTO\Response $response){
        try{
            $this->registroAjustePeriodoBaseService->entityManager->beginTransaction();
            
            $row = $request->getRow();
            
            $this->registroAjustePeriodoBaseService->deleteLancamentos($row);
            
            $this->registroAjustePeriodoBaseService->entityManager->commit();
        }
        catch (\Exception $e) {
            $this->registroAjustePeriodoBaseService->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
    
    public function validaHistorico(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $historicoCtbl = $this->registroAjustePeriodoBaseService->validaHistorico($row);
            
            $response->addDataSet(new DataSet('historicoCtbl', $historicoCtbl));
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
    
    public function deleteRegistro(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $dadosContaB = $this->registroAjustePeriodoBaseService->adqDadosParteB($row);
            $dadosLançamentos = $this->registroAjustePeriodoBaseService->adqContasLancParteA($row);
            if($dadosContaB || $dadosLançamentos){
                 $response->addDataSet(new DataSet('response', [true]));
            }else{
                 $response->addDataSet(new DataSet('response', [false]));
            }
                
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveParteB(DTO\Request $request, DTO\Response $response) {
       try{
            $this->registroAjustePeriodoBaseService->entityManager->beginTransaction();
            
            $row = $request->getRow();
            $dadosContaB = $this->registroAjustePeriodoBaseService->adqDadosParteB($row);
            if($row['CDCONTCTBL'] == ''){
                $this->registroAjustePeriodoBaseService->apagaParteB($row);
                
            }else{
            
                $this->registroAjustePeriodoBaseService->saveParteB($row);
            }
            $this->registroAjustePeriodoBaseService->entityManager->commit();
            
       }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function delete(DTO\Request $request, DTO\Response $response) {
       try{
            //$dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 16);
            $this->dataSourceName = "lalurpartea";
            parent::delete($request, $response);
       }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

}